unit Testu;

interface

uses
  SysUtils, WinTypes, WinProcs, Messages, Classes, Graphics, Controls,
  Forms, Dialogs, VidLab16, ExtCtrls, StdCtrls, Menus, Audio;

type
  TMainForm = class(TForm)
    Panel1: TPanel;
    VideoCaptureParms: TVideoCaptureParms;
    VideoAudioParms: TVideoAudioParms;
    VideoLab: TVideoLab;
    Panel: TPanel;
    DriverName: TLabel;
    labelStatus: TLabel;
    MainMenu: TMainMenu;
    MenuFile: TMenuItem;
    MenuEdit: TMenuItem;
    MenuVideo: TMenuItem;
    MenuPlayback: TMenuItem;
    MenuSetup: TMenuItem;
    MenuExit: TMenuItem;
    MenuEditCopy: TMenuItem;
    MenuActive: TMenuItem;
    MenuPause: TMenuItem;
    N1: TMenuItem;
    MenuPreview: TMenuItem;
    MenuOverlay: TMenuItem;
    N2: TMenuItem;
    MenuBeginCapture: TMenuItem;
    N3: TMenuItem;
    MenuSaveDIB: TMenuItem;
    MenuSaveBitmap: TMenuItem;
    MenuOpen: TMenuItem;
    MenuOpenExternal: TMenuItem;
    N4: TMenuItem;
    MenuPlay: TMenuItem;
    MenuClose: TMenuItem;
    MenuFormat: TMenuItem;
    MenuSource: TMenuItem;
    MenuDisplay: TMenuItem;
    MenuCompress: TMenuItem;
    N5: TMenuItem;
    MenuSetAudioFormat: TMenuItem;
    procedure MenuExitClick(Sender: TObject);
    procedure MenuEditCopyClick(Sender: TObject);
    procedure MenuActiveClick(Sender: TObject);
    procedure MenuPauseClick(Sender: TObject);
    procedure MenuPreviewClick(Sender: TObject);
    procedure MenuOverlayClick(Sender: TObject);
    procedure MenuBeginCaptureClick(Sender: TObject);
    procedure MenuSaveDIBClick(Sender: TObject);
    procedure MenuSaveBitmapClick(Sender: TObject);
    procedure MenuFormatClick(Sender: TObject);
    procedure MenuSourceClick(Sender: TObject);
    procedure MenuDisplayClick(Sender: TObject);
    procedure MenuCompressClick(Sender: TObject);
    procedure MenuSetAudioFormatClick(Sender: TObject);
    procedure MenuOpenClick(Sender: TObject);
    procedure MenuOpenExternalClick(Sender: TObject);
    procedure MenuPlayClick(Sender: TObject);
    procedure MenuCloseClick(Sender: TObject);
    procedure FormCreate(Sender: TObject);
    function VideoLabError(Sender: TObject; nId: Integer;
      pMsg: PChar): Longint;
    function VideoLabFrame(Sender: TObject; pVideo: PVideoHdr): Longint;
    function VideoLabStatus(Sender: TObject; nId: Integer;
      pMsg: PChar): Longint;
  private
    nFrameCount: Integer;
  private
    procedure SetupMenu;
  end;

var
  MainForm: TMainForm;
  DriverCaps:  TVideoDriverCaps;
  VideoStatus: TVideoStatus;

implementation

{$R *.DFM}

procedure TMainForm.SetupMenu;
begin
  { Get current status }
  VideoLab.GetStatus(@VideoStatus);

  { Set menu items }
  MenuActive .Checked := VideoLab.Active;
  MenuPreview.Checked := VideoStatus.fLiveWindow;
  MenuOverlay.Checked := VideoStatus.fOverlayWindow;
end;

procedure TMainForm.MenuExitClick(Sender: TObject);
begin
  MainForm.Close;
end;

procedure TMainForm.MenuEditCopyClick(Sender: TObject);
begin
  { Copy frame to the clip board }
  VideoLab.EditCopy;
end;

procedure TMainForm.MenuActiveClick(Sender: TObject);
var
  pTmp: array[0..80] of Char;
begin
  { Toggel video. }
  if (VideoLab.Active)
     then VideoLab.Active := False
     else VideoLab.Active := True;

  { Display }
  if (Not VideoLab.Active) then
     DriverName.Caption := ''
  else
  begin
     { Get driver name }
     VideoLab.GetDriverName(0, pTmp, 80);
     DriverName.Caption := pTmp;
     VideoLab.GetDriverVersion(0, pTmp, 80);
     DriverName.Caption := DriverName.Caption + ' ' + pTmp;
  end;

  { Get driver caps }
  VideoLab.GetDriverCaps(@DriverCaps);

  { Get current status }
  VideoLab.GetStatus(@VideoStatus);
end;

procedure TMainForm.MenuPauseClick(Sender: TObject);
begin
  { Stop on the current frame }
  VideoLab.GrabFrame(True);
end;

procedure TMainForm.MenuPreviewClick(Sender: TObject);
begin
  { Turn on Preview Mode }
  VideoLab.Preview     := True;
  VideoLab.PreviewRate := 1;

  { Clear frame counter }
  nFrameCount := 0;
end;

procedure TMainForm.MenuOverlayClick(Sender: TObject);
begin
  { Turn on Overlay Mode }
  VideoLab.Overlay := True;
end;

procedure TMainForm.MenuBeginCaptureClick(Sender: TObject);
begin
  { Start capturing the video }
  VideoLab.Sequence;
end;

procedure TMainForm.MenuSaveDIBClick(Sender: TObject);
begin
  { Use video driver to save current frame }
  VideoLab.FileSaveDIB('Test.Bmp');
end;

procedure TMainForm.MenuSaveBitmapClick(Sender: TObject);
begin
  { Get current status }
  VideoLab.GetStatus(@VideoStatus);

  { Live? }
  if (VideoStatus.fOverlayWindow)
     then MessageDlg('Video can not be in Overlay mode.', mtError, [mbOK], 0)
     { Save the current frame window to file }
     else VideoLab.SaveToBitmap(8, BI_RLE8, 'Test.Bmp');
end;

procedure TMainForm.MenuFormatClick(Sender: TObject);
begin
  { Display dialog }
  if (DriverCaps.fHasDlgVideoFormat)
     then VideoLab.FormatDialog
     else MessageDlg('Not supported by video driver', mtInformation, [mbOK], 0);
end;

procedure TMainForm.MenuSourceClick(Sender: TObject);
begin
  { Display dialog }
  if (DriverCaps.fHasDlgVideoSource)
     then VideoLab.SourceDialog
     else MessageDlg('Not supported by video driver', mtInformation, [mbOK], 0);
end;

procedure TMainForm.MenuDisplayClick(Sender: TObject);
begin
  { Display dialog }
  if (DriverCaps.fHasDlgVideoDisplay)
     then VideoLab.DisplayDialog
     else MessageDlg('Not supported by video driver', mtInformation, [mbOK], 0);
end;

procedure TMainForm.MenuCompressClick(Sender: TObject);
begin
  { Display dialog }
  VideoLab.CompressionDialog;
end;

procedure TMainForm.MenuSetAudioFormatClick(Sender: TObject);
var
  audio:   TFormAudio;
begin
  audio := TFormAudio.Create(Self);

  { Sample Rate }
  if (VideoAudioParms.BitsPerSample = 8)
     then audio.rb8bit .Checked := True
     else audio.rb16bit.Checked := True;

  { Channels }
  if (VideoAudioParms.Channels = 1)
     then audio.rbMono  .Checked := True
     else audio.rbStereo.Checked := True;

  { Frequency }
  case (VideoAudioParms.SamplesPerSec) of
     0..8000     : audio.rb8khz .Checked := True;
     8001..11025 : audio.rb11khz.Checked := True;
     11026..22050: audio.rb22khz.Checked := True;
     else
        audio.rb44khz.Checked := True;
  end;

  { Do dialog }
  if (audio.ShowModal = mrOk) then
  begin
     { Sample Rate }
     if (audio.rb8bit .Checked) then VideoAudioParms.BitsPerSample :=  8;
     if (audio.rb16bit.Checked) then VideoAudioParms.BitsPerSample := 16;

     { Channels }
     if (audio.rbMono  .Checked) then VideoAudioParms.Channels := 1;
     if (audio.rbStereo.Checked) then VideoAudioParms.Channels := 2;

     { Frequency }
     if (audio.rb8khz .Checked) then VideoAudioParms.SamplesPerSec :=  8000;
     if (audio.rb11khz.Checked) then VideoAudioParms.SamplesPerSec := 11025;
     if (audio.rb22khz.Checked) then VideoAudioParms.SamplesPerSec := 22050;
     if (audio.rb44khz.Checked) then VideoAudioParms.SamplesPerSec := 44100;
  end;
end;

procedure TMainForm.MenuOpenClick(Sender: TObject);
var
  pTmp:  array[0..256] of Char;
begin
  { Load play back file }
  StrPCopy(pTmp,VideoLab.AVIFileName);
  VideoLab.PlaybackLoad(True, MCIWNDF_SHOWNAME, pTmp);

  { Menu }
  SetupMenu;
end;

procedure TMainForm.MenuOpenExternalClick(Sender: TObject);
var
  pTmp:  array[0..256] of Char;
begin
  { Load play back file }
  StrPCopy(pTmp,VideoLab.AVIFileName);
  VideoLab.PlaybackLoad(False, MCIWNDF_SHOWNAME, pTmp);

  { Menu }
  SetupMenu;
end;

procedure TMainForm.MenuPlayClick(Sender: TObject);
begin
  { Start play back }
  VideoLab.PlaybackStart;
end;

procedure TMainForm.MenuCloseClick(Sender: TObject);
begin
  { Remove playback window }
  VideoLab.PlaybackUnload;
end;

procedure TMainForm.FormCreate(Sender: TObject);
begin
  { Variables }
  nFrameCount := 0;

  { Reset all video windows }
  VideoLab.Reset;

  { Turn on video }
  MenuActiveClick(Sender);
end;

function TMainForm.VideoLabError(Sender: TObject; nId: Integer;
  pMsg: PChar): Longint;
begin
  { Display error message }
  MessageDlg( StrPas(pMsg), mtError, [mbOK], 0);
  VideoLabError := 1;
end;

function TMainForm.VideoLabFrame(Sender: TObject;
  pVideo: PVideoHdr): Longint;
begin
  { Show that we are really doing something }
  nFrameCount    := nFrameCount + 1;
  labelStatus.Caption := Format('Frame: %d', [nFrameCount]);
  VideoLabFrame  := 1;
end;

function TMainForm.VideoLabStatus(Sender: TObject; nId: Integer;
  pMsg: PChar): Longint;
begin
  { Show the current status }
  labelStatus.Caption := StrPas(pMsg);
  VideoLabStatus      := 1;

  { Menu }
  SetupMenu;
end;

end.
